#! /usr/bin/python
# -*- coding: utf-8 -*-

# MESSUNG VERARBEITEN
#
# Autor: Christian Stade-Schuldt (http://www.tafkas.org/)
# Autor: Stefan Salich (http://www.salich.de)
# Datum: 2014-08-31

# $Id: gettemp.py 2711 2014-11-09 13:19:07Z sst $

# BESCHREIBUNG
# Dieses Python-Skript hat den Zweck auf einem Raspberry Pi
# Werte von Temperatursensoren zu lesen, in einer Round-
# Robin-Datenbank zu speichern und ggf. auch auf einem zweizeiligen
# LC-Display auszugeben.
#
# Sollten schon Messwerte vorliegen, koennen diese im Format fuer
# "rrdtool update" ueber geben werden. Der erste uebergebene Wert wird
# gegen den ersten hier gelesenen gelegt. Es wir dann immer der
# niedrigere gewaehlt, da ich davon ausgehe das auf den einen Sensor
# die Sonne scheint :)
#
# Konfiguriert werden muss dieses Skript auch! Der Bereich ist markiert.

import re, os, rrdtool, time, sys
import lcd


### BEGINN KONFIGURATION ####

# define pathes to 1-wire sensor data
pathes = (
	"/sys/bus/w1/devices/28-000006098113/w1_slave",
	"/sys/bus/w1/devices/28-0004441b38ff/w1_slave"
)

# define Text zum Sensor. Der Text darf maximal 11 Zeichen lang sein.
text = (
  "Aussen: ",
	"Innen:  "
)

# Dateien in die der letzte Wert gespeichert werden soll
dateien = (
	"/var/www/data/temp_wasser.txt",
	"/var/www/data/temp_luft.txt"
)

### ENDE KONFIGURATION ###


# Read Sensor
# Sensor lesen und parsen
def read_sensor(path):
	value = "U"
	try:
		f = open(path, "r")
		line = f.readline()
		if re.match(r"([0-9a-f]{2} ){9}: crc=[0-9a-f]{2} YES", line):
			line = f.readline()
			m = re.match(r"([0-9a-f]{2} ){9}t=([+-]?[0-9]+)", line)
			if m:
				value = str(float(m.group(2)) / 1000.0)
				if (85 == float(value)):
					print "Wert ist 85.0 und somit undefiniert"
					value = "U"
		f.close()
	except (IOError), e:
		print time.strftime("%x %X"), "Error reading", path, ": ", e
	return value

# function: is_number
def is_number(s):
	try:
		float(s)
		return True
	except ValueError:
		pass
	return False

# Wert fuer LCD
# Wert U und 85 oder hoeher sind ungueltig
def value4lcd(v):
	if (value != "U") and (85 > float(value)):
		return str(round(float(value),1))
	else:
		return "--"

# Messwerte uebergeben?
arg_num = len(sys.argv)
if (1 < arg_num):
	# Messwerte in Array sichern
	messung = str(sys.argv[1]).split(':')
	# Erstes Element mit Zeit (N) entfernen
	messung.pop(0)
else:
	messung = []
	
# Sensoren lesen
data = 'N'
lcd_zeilen = []
for path in pathes:
	# Wert aus Datenquelle lesen
	data += ':'
	value = "U"

	# Maximal 5 mal probieren einen gueltigen Wert zu lesen
	for i in range(1,5):
		value = read_sensor(path)
		print "Lesen " + str(i) + ". Versuch = " + value
		if ("U" != value):
			break
		else:
			time.sleep(1)

	# Wurden noch Messwerte uebergeben?
	if (0 < len(messung)):
		value2 = messung.pop(0)
		print "Messwert WDE1-USB: " + str(value2) + ", Messwert Kabelsensor: " + str(value)
		
		# Ist der Wert eine gueltige Zahl?
		if (is_number(value2)):
			if (is_number(value)):
				# Messwerte in float wandeln
				a = float(value2)
				b = float(value)
		
				# Kleineren Wert (Schattenwert) verwenden
				if a < b:
					value = value2
					print "Wert von WDE1-USB war kleiner!"

	data += value
	time.sleep(1)

	# Wert fuer LCD sichern
	lcd_zeilen.append(value4lcd(value))
	
	# Leerzeile
	print

# Weitere uebergebene Messwerte verarbeiten
for m in messung:
	data += ":" + m

# Zwei Temperaturen auf LCD ausgeben
lcd.init()
grad = " " + chr(223) + "C"
lcd.schreiben(text[0] + lcd_zeilen[0] + grad, text[1] + lcd_zeilen[1] + grad)
lcd.clean()

# Werte in Dateien schreiben
for i in range(0, len(dateien)):
	# Keine ungueltigen Werte sichern
	if lcd_zeilen[i] != "--":
		fh = open(dateien[i], "w")
		fh.write(lcd_zeilen[i])
		fh.close()

# Daten die gesichert werden ausgeben
print "Daten: " + data

# Daten in Round-Robin-Datenbank schreiben
rrdtool.update(
	"%s/wetter.rrd" % (os.path.dirname(os.path.abspath(__file__))),
	data)

# eof
